@@ -344,7 +344,7 @@ ObjectPtr Private::JSONToEvent(const QVariantMap& data, const QString &timezone)
         } else if (!timezone.isEmpty()) {
             const QTimeZone tz(timezone.toUtf8());
             if (tz.isValid()) {
-                dtStart.setTimeZone(tz);;
+                dtStart.setTimeZone(tz);
             } else {
                 qCWarning(KGAPIDebug) << "Invalid timezone" << timezone;
             }
@@ -877,7 +877,7 @@ static QMap<QString, QString> initMSStandardTimeTZTable()
     /* Based on "Microsoft Time Zone Index Values"
      * http://support.microsoft.com/kb/973627
      *
-     * The mapping is not exact, since the the TZID usually refers to a
+     * The mapping is not exact, since the TZID usually refers to a
      * region of multiple countries, so I always picked one of the countries
      * in the specified region and used it's TZID.
      *
@@ -1002,7 +1002,7 @@ QString Private::checkAndConverCDOTZID(const QString& tzid, const EventPtr& even
     const QStringList properties = vcard.split(QLatin1Char('\n'));
     int CDOId = -1;
     for (const QString &property : properties) {
-        if (property.startsWith(QStringLiteral("X-MICROSOFT-CDO-TZID"))) {
+        if (property.startsWith(QLatin1String("X-MICROSOFT-CDO-TZID"))) {
             QStringList parsed = property.split(QLatin1Char(':'));
             if (parsed.length() != 2) {
                 break;
