@@ -28,8 +28,8 @@
 #include "utils.h"
 #include "private/queuehelper_p.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 
 
 using namespace KGAPI2;
@@ -70,7 +70,7 @@ void EventMoveJob::Private::processNextEvent()
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
@@ -95,7 +95,7 @@ EventMoveJob::EventMoveJob(const EventsList &events, const QString &sourceCalend
     ModifyJob(account, parent),
     d(new Private(this))
 {
-    Q_FOREACH(const EventPtr &event, events) {
+    for (const EventPtr &event : events) {
         d->eventsIds << event->uid();
     }
     d->source = sourceCalendarId;
