@@ -50,7 +50,7 @@ class KGAPIDRIVE_EXPORT ChildReference: public KGAPI2::Object
   public:
     explicit ChildReference(const QString &id);
     explicit ChildReference(const ChildReference &other);
-    virtual ~ChildReference();
+    ~ChildReference() override;
 
     /**
      * @brief Returns the id of the child.
