@@ -26,7 +26,7 @@
 #include "account.h"
 #include "driveservice.h"
 
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
@@ -68,7 +68,7 @@ PermissionDeleteJob::PermissionDeleteJob(const QString &fileId,
     d(new Private)
 {
     d->fileId = fileId;
-    Q_FOREACH(const PermissionPtr & permission, permissions) {
+    for (const PermissionPtr & permission : qAsConst(permissions)) {
         d->permissionsIds << permission->id();
     }
 }
